@@ -6,7 +6,7 @@ from .wog_abs import WoG
 from .MemoryGame import MemoryGame
 from .GuessGame import GuessGame
 from .CurrencyRGame import CurrencyRGame
-from currency_converter import CurrencyConverter
+from .currency_converter import CurrencyConverter
 #__all__ = ['get_user_name', 'Factory', 'GuessGame', 'mainGame',
 #           'MemoryGame', 'utils', 'wog_abs']
 
